Crate silpkg

Crate silpkg 

silpkg is a library for interacting with SIL PKG files

Features

This library separates parsing/modification logic from IO by using coroutines and aims to support many ways of interfacing with the base logic module. Currently only a synchronous interface is implemented in sync.

  • Sync
    • reading PKG files
    • reading uncompressed entries
    • adding uncompressed entries
    • reading deflate compressed entries
    • adding deflate compressed entries
    • creating new PKG files
  • Slice
  • Async

Quick start

To open an existing archive use Pkg::parse. To create a new archive use Pkg::create. For information on how to interact with archives look around in Pkg.

Re-exports

pub use sync::Truncate;std

Modules

errors
Defines all the errors used by this library.
syncstd
A synchronous interface for reading and writing PKG archives.

Structs

Compression
When compressing data, the compression level can be specified by a value in this struct.
EntryInfo
Information about an entry present in the archive.
Flags
Flags that change the way entries are written.

Enums

EntryCompression
An enum that specifies the ways entries can be compressed.