RepackError

Type Alias RepackError 

pub type RepackError = RepackError<Error>;
Available on crate feature std only.
RepackError returned by sync::Pkg.

Aliased Type

pub enum RepackError {
    OverlappingEntries,
    Io(Error),
}

Variants



OverlappingEntries

The archive contained overlapping entries.

This cannot be triggered by creating your own archive and can only happen if you parse an archive that contains such overlapping entries and try to repack it.



Io(Error)

An IO error occurred.